@@ -1,9 +1,10 @@
 package Mongoose;
 BEGIN {
-  $Mongoose::VERSION = '0.01_01';
+  $Mongoose::VERSION = '0.01_02';
 }
 use MongoDB;
 use MooseX::Singleton;
+use Mongoose::Join;
 use Mongoose::Meta::AttributeTraits;
 
 has '_db' => ( is => 'rw', isa => 'HashRef[MongoDB::Database]' );
@@ -51,11 +52,11 @@ sub _db_for_class {
 
 =head1 NAME
 
-Mongoose
+Mongoose - MongoDB document to Moose object mapper
 
 =head1 VERSION
 
-version 0.01_01
+version 0.01_02
 
 =head1 SYNOPSIS
 
@@ -67,10 +68,12 @@ version 0.01_01
 	package main;
 	use Mongoose;
 
+    Mongoose->db( 'mydb' ); 
 	my $person = Person->new( name=>'Jack' );
 	$person->save;
 
 	my $person = Person->find_one({ name=>'Jack' });
+    say $person->name; # Jack
 
 	my $cursor = Person->find({ name=>'Jack' });
 	die "Not found" unless defined $cursor;
@@ -82,7 +85,7 @@ version 0.01_01
 
 =head1 DESCRIPTION
 
-This is a MongoDB-Moose object mapper. This module allows you to use the full
+This is a MongoDB to Moose object mapper. This module allows you to use the full
 power of MongoDB within your Moose classes, without sacrificing MongoDB's
 power, flexibility and speed.
 
@@ -104,7 +107,8 @@ Sets the current MongoDB connection and/or db name.
 The connection defaults to whatever MongoDB defaults are
 (tipically localhost:27017).
 
-For more control over the connection, with options:
+For more control over the connection, C<db> takes the same parameters as
+L<MongoDB::Connection>, plus C<db_name>. 
 
 	my $db = Mongoose->db(
 		host          => 'mongodb://localhost:27017',
@@ -113,9 +117,9 @@ For more control over the connection, with options:
 	);
 
 This will, in turn, instantiate a C<MongoDB::Connection> instance
-with all giving parameters. 
+with all given parameters. 
 
-=head2 naming (isa: Coderef)
+=head2 naming 
 
 By default, Mongoose converts package names into collections by replacing
 double-colon C<::> with underscores C<_>, separating camel-case,
@@ -124,17 +128,18 @@ such as C<aB> with C<a_b> and uppercase with lowercase letters.
 This method let's you change this behaviour, by setting
 setting the collection naming default sub. 
 
-The closure gets the package name as first parameter and 
-returns the collection name. 
+The closure receives the package name as first parameter and 
+should return the collection name. 
 
 	# let me change the naming strategy
 	#  for my mongo collections
-	#  to lowercase 
+	#  to plain lowercase 
 	Mongoose->naming(sub{ lc( shift ) }); 
 
 =head2 connection
 
-The current connection object, of class L<MongoDB::Connection>.
+Sets/returns the current connection object, of class L<MongoDB::Connection>.
+
 Defaults to whatever MongoDB defaults.
 
 =head1 REPOSITORY
@@ -145,12 +150,22 @@ Fork me on github: L<http://github.com/rodrigolive/mongoose>
 
 This is a WIP, barely *beta* quality software. 
 
-Report bugs via RT. File test cases.
+Report bugs via RT. Send me test cases.
 
 =head1 TODO
 
 * Better error control
+
 * Finish-up multiple database support
+
 * Allow query->fields to control which fields get expanded into the object. 
+
 * Cleanup internals.
-* More tests and use cases.
\ No newline at end of file
+
+* More tests and use cases.
+
+* Better documentation.
+
+=head1 SEE ALSO
+
+L<KiokuDB>
\ No newline at end of file
